# Changelog

## [0.2.2](https://github.com/pshrest2/azure-upload-benchmark/compare/v0.2.1...v0.2.2) (2026-03-23)


### Documentation

* update installation instruction ([fce7297](https://github.com/pshrest2/azure-upload-benchmark/commit/fce7297e7d1c5b073dace8af5cbc46d322f9a5c4))

## [0.2.1](https://github.com/pshrest2/azure-upload-benchmark/compare/v0.2.0...v0.2.1) (2026-03-23)


### Bug Fixes

* use custom release please token ([e4f7901](https://github.com/pshrest2/azure-upload-benchmark/commit/e4f790127dd1f130be9c1376a304b374d6c29436))

## [0.2.0](https://github.com/pshrest2/azure-upload-benchmark/compare/v0.1.0...v0.2.0) (2026-03-23)


### Features

* add py.typed marker for PEP 561 support ([2e803df](https://github.com/pshrest2/azure-upload-benchmark/commit/2e803dff0d9747a7b8c366c470317a56a17420ce))

## 0.1.0 (2026-03-23)


### Features

* add precommit hooks for conventional commits format ([7e462df](https://github.com/pshrest2/azure-upload-benchmark/commit/7e462df8aa34324ff76bb0ff59c70698b84aa48c))
* initialize azure-upload-benchmark project ([0b366a0](https://github.com/pshrest2/azure-upload-benchmark/commit/0b366a059a05f212da5f0d2b2f9ad0b57635a96e))


### Bug Fixes

* username typo ([17aaeb6](https://github.com/pshrest2/azure-upload-benchmark/commit/17aaeb69f81fae19a7e2710f906d28bb50908946))
